use std::io::{Read, Write};

use miette::{Context, IntoDiagnostic};
use sercon_base::Backend;
use serde_value::Value;

#[derive(Default)]
pub struct NbtBackend;

impl Backend for NbtBackend {
    fn serialize(&self, out: &mut dyn Write, data: Value) -> miette::Result<()> {
        nbt::to_writer(out, &data, None)
            .into_diagnostic()
            .wrap_err("NBT serialization error")
    }

    fn deserialize(&self, data: &mut dyn Read) -> miette::Result<Value> {
        nbt::from_reader(data)
            .into_diagnostic()
            .wrap_err("NBT deserialization error")
    }
}

impl_filetype_backend!(NbtBackend, ["nbt"]);
